.. _Python: http://www.python.org/
.. _Click: http://click.pocoo.org/6/
.. _Click Setuptools Integration: http://click.pocoo.org/6/setuptools/
.. _Documentation: https://klak.readthedocs.io
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

=====
Klak
=====

.. image:: https://img.shields.io/pypi/v/klak.svg
        :target: https://pypi.python.org/pypi/klak

.. image:: https://img.shields.io/travis/aubricus/klak.svg
        :target: https://travis-ci.org/aubricus/klak

.. image:: https://readthedocs.org/projects/klak/badge/?version=latest
        :target: https://klak.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/aubricus/klak/shield.svg
     :target: https://pyup.io/repos/github/aubricus/klak/
     :alt: Updates

---------------------------------------

*"Clak [klak]: A sharp sound or series of sounds."*

**Click n' Klak**!

`klak` is a micro-wrapper around `Click`_ that combines the ease of a *simple Makefile* and the power of `Python`_ and `Click`_!


Support
-------

* Python 3.6.x
* Python 3.5.x

License
--------

Free software: GNU General Public License v3

Documentation
--------------
* See the main `Documentation`_

Features
--------

* Auto-load a `Clickfile` in the current working directory.
* Easily append commands to an available `cli.root` group.
* Easily append nested groups and commands as well.
* Ships with `Click`_ automatically setup with the recommended `Click Setuptools Integration`_.
* Bash completions available!

Credits
-------

* This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.


